@@ -3,19 +3,19 @@ use cogo::coroutine::sleep;
 use cogo::{defer, go};
 
 fn main(){
-    defer!(||{
+    defer!({
         println!("guard: 1");
     });
     defer!(||{
         println!("guard: 2");
     });
-    defer!(||{
+    defer!{
+        println!("guard: 3");
+    }
+    defer!{
         go!(||{
-            defer!(||{
-                println!("---------------defer in go!-------------");
-            });
             println!("go spawn!");
         });
-    });
+    };
     panic!("None Exception!");
 }
\ No newline at end of file
