@@ -16,7 +16,6 @@ use crossbeam::utils::Backoff;
 
 #[cfg(nightly)]
 use std::intrinsics::likely;
-
 #[cfg(not(nightly))]
 #[inline]
 fn likely(e: bool) -> bool {
@@ -91,7 +90,7 @@ impl ParkStatus {
 #[inline(never)]
 fn init_scheduler() {
     let workers = config().get_workers();
-    let b: Box<Scheduler> = Scheduler::new(workers, config().get_work_steal());
+    let b: Box<Scheduler> = Scheduler::new(workers);
     unsafe {
         SCHED = Box::into_raw(b);
     }
@@ -139,9 +138,6 @@ pub fn get_scheduler() -> &'static Scheduler {
 
 #[inline]
 fn steal_global<T>(global: &deque::Injector<T>, local: &deque::Worker<T>) -> Option<T> {
-    if global.is_empty() {
-        return None;
-    }
     static GLOBABLE_LOCK: AtomicUsize = AtomicUsize::new(0);
     if GLOBABLE_LOCK
         .compare_exchange(0, 1, Ordering::Relaxed, Ordering::Relaxed)
@@ -178,19 +174,15 @@ fn steal_local<T>(stealer: &deque::Stealer<T>, local: &deque::Worker<T>) -> Opti
 pub struct Scheduler {
     pub pool: CoroutinePool,
     event_loop: EventLoop,
-    /// FIFO deque
     global_queue: deque::Injector<CoroutineImpl>,
-    /// FIFO deque
     local_queues: Vec<deque::Worker<CoroutineImpl>>,
     pub(crate) workers: ParkStatus,
     timer_thread: TimerThread,
-    is_steal: bool,
     stealers: Vec<Vec<(usize, deque::Stealer<CoroutineImpl>)>>,
-    last_local: AtomicUsize,
 }
 
 impl Scheduler {
-    pub fn new(workers: usize, is_steal: bool) -> Box<Self> {
+    pub fn new(workers: usize) -> Box<Self> {
         let mut local_queues = Vec::with_capacity(workers);
         (0..workers).for_each(|_| local_queues.push(deque::Worker::new_fifo()));
         let mut stealers = Vec::with_capacity(workers);
@@ -212,50 +204,41 @@ impl Scheduler {
             timer_thread: TimerThread::new(),
             workers: ParkStatus::new(workers),
             stealers,
-            is_steal,
-            last_local: AtomicUsize::new(0),
         })
     }
 
     pub fn run_queued_tasks(&self, id: usize) {
         let local = unsafe { self.local_queues.get_unchecked(id) };
-        if self.is_steal {
-            let stealers = unsafe { self.stealers.get_unchecked(id) };
-            loop {
-                // Pop a task from the local queue
-                let co = local.pop().or_else(|| {
-                    // Try stealing a of task from other local queues.
-                    let parked_threads = self.workers.parked.load(Ordering::Relaxed);
-                    stealers
-                        .iter()
-                        .map(|s| {
-                            if parked_threads & (1 << s.0) != 0 {
-                                return None;
-                            }
-                            steal_local(&s.1, local)
-                        })
-                        .find_map(|r| r)
-                        // Try stealing a batch of tasks from the global queue.
-                        .or_else(||
-                            {
-                                steal_global(&self.global_queue, local)
-                            })
-                });
-                if let Some(co) = co {
-                    run_coroutine(co);
-                } else {
-                    // do a re-check
-                    if self.global_queue.is_empty() {
-                        break;
-                    }
-                }
-            }
-        } else {
-            loop {
-                // Pop a task from the local queue
-                if let Some(co) = local.pop() {
-                    run_coroutine(co);
-                } else {
+        let stealers = unsafe { self.stealers.get_unchecked(id) };
+        loop {
+            // Pop a task from the local queue
+            let co = local.pop().or_else(|| {
+                // Try stealing a of task from other local queues.
+                let parked_threads = self.workers.parked.load(Ordering::Relaxed);
+                stealers
+                    .iter()
+                    .map(|s| {
+                        if parked_threads & (1 << s.0) != 0 {
+                            return None;
+                        }
+                        steal_local(&s.1, local)
+                    })
+                    .find_map(|r| r)
+                    // Try stealing a batch of tasks from the global queue.
+                    .or_else(|| {
+                        if self.global_queue.is_empty(){
+                            None
+                        }else{
+                            steal_global(&self.global_queue, local)
+                        }
+                    })
+            });
+
+            if let Some(co) = co {
+                run_coroutine(co);
+            } else {
+                // do a re-check
+                if self.global_queue.is_empty() {
                     break;
                 }
             }
@@ -266,9 +249,9 @@ impl Scheduler {
     #[inline]
     pub fn schedule(&self, co: CoroutineImpl) {
         #[cfg(nightly)]
-            let id = WORKER_ID.load(Ordering::Relaxed);
+        let id = WORKER_ID.load(Ordering::Relaxed);
         #[cfg(not(nightly))]
-            let id = WORKER_ID.with(|id| id.load(Ordering::Relaxed));
+        let id = WORKER_ID.with(|id| id.load(Ordering::Relaxed));
 
         if id == !1 {
             self.schedule_global(co);
@@ -277,27 +260,12 @@ impl Scheduler {
         }
     }
 
-    /// put the coroutine to global queue(if is_steal) so that next time it can be scheduled
-    /// pub the coroutine to any local_queues(if !is_steal) so that next time it can be scheduled
+    /// put the coroutine to global queue so that next time it can be scheduled
     #[inline]
     pub fn schedule_global(&self, co: CoroutineImpl) {
-        if self.is_steal {
-            self.global_queue.push(co);
-            // signal one waiting thread if any
-            self.workers.wake_one(self);
-        } else {
-            //Save them to other work queues in sequence to avoid putting them into global queues and reduce locking
-            //Here we use atomic variables to store the worker thread ID of the last execution to ensure that the coroutine for this execution is evenly distributed to each worker thread
-            let mut last_id = self.last_local.load(Ordering::Relaxed);
-            if last_id + 1 >= self.local_queues.len() {
-                last_id = 0;
-            } else {
-                last_id += 1;
-            }
-            unsafe { self.local_queues.get_unchecked(last_id) }.push(co);
-            self.last_local.store(last_id, Ordering::Release);
-            self.get_selector().wakeup(last_id);
-        }
+        self.global_queue.push(co);
+        // signal one waiting thread if any
+        self.workers.wake_one(self);
     }
 
     #[inline]
